import React from "react";
import lodash from "lodash";
import {LoggerFactory} from "reakit/src/utils";
import styles from "./styles";
//import {OptionType} from "../types";
import i18n from "reakit/src/i18n";

let Logger = new LoggerFactory("select.value", {level:"error"});

/**
 * Main component class.
 */
export default class Component extends React.Component {
    /** React properties **/
    static displayName = "select.value";
    static defaultProps = {
        multi: false,
        onRemove: ()=>{}
    };
    static propTypes = {
        multi: React.PropTypes.bool,
        onRemove: React.PropTypes.func
    };

    /**
     * LYFECICLE : This function is called when component
     * got mounted in the view.
     */
    componentDidMount() {
        let logger = Logger.create("componentDidMount");
        logger.info("enter");
    }

    /**
     * This function is responsible for generating the component's view.
     */
    render() {
        let logger = Logger.create("render");
        logger.info("enter", {option: this.props.option});

        if(!this.props.option){return null;}

        let {option,multi} = this.props;
        option = lodash.isString(option)?{value:option,label:option}:option;
        let {value,label} = option;

        return multi ? (
            <span role="option" aria-selected="true" key={value} className={styles.valueMulti}>
                <span className={styles.valueMultiRemove} onMouseDown={(evt) => {
                    evt.stopPropagation();
                    evt.preventDefault();
                    this.props.onRemove(value);
                }} aria-hidden="true">
                    <span className="icon-delete2"></span>
                </span>
                <div className={styles.valueMultiBody}>
                    <i18n.Translate text={label}/>
                </div>
            </span>
        ) : (
            <div className={styles.valueSingle}>
                <i18n.Translate text={label}/>
            </div>
        );
    }
}
