import axios from "axios";
import LoggerFactory from "reakit/src/utils/logger";
import Storage from "reakit/src/utils/storage";
import qs from "qs";

let Logger = new LoggerFactory("utils.http");

/**
 * Main class definition.
 */
export default class Http {
    constructor(opts={}) {
        if(opts.shared){Http.shared = this;}

        this.storage = new Storage();
        this.authTokenKey = opts.authTokenKey || "@authToken";
    }

    /****************************************************************
    * Instance methods
    ****************************************************************/
    async getAuthToken() {
        return await this.storage.get(this.authTokenKey);
    }

    async setAuthToken(token) {
        return await this.storage.set(this.authTokenKey, token);
    }

    async request(method, url, data, opts = {}) {
        let logger = Logger.create("request");

        logger.info("enter", {
            method: method,
            url: url,
            data: data,
            opts: opts
        });

        let reqOpts = {
            method: method.toUpperCase(),
            url: url,
            headers: {},
            paramsSerializer: function(params) {
                return qs.stringify(params);
            }
        };

        if(data) {
            if(reqOpts.method == "GET"){ reqOpts.params = data; }
            else { reqOpts.data = data; }
        }

        // Auth token
        try {
            let token = await this.getAuthToken();
            reqOpts.headers.Authorization = `Bearer ${token}`;

            logger.debug("getAuthToken success", {token});
        }
        catch(error) {
            logger.error("getAuthToken error", error);
        }

        // Send request
        return axios(reqOpts)
        .then((response) => {
            logger.debug("response", response);
            return response.data;
        });
    }
}
